==> ej2-treemap-16.3.34.tgz: package/README.md <==
# ej2-treemap

The tree map control provides a simple and effective way to visualize flat or hierarchical data as clustered rectangles with a specific, weighted attribute determining the size of each rectangle.

![TreeMap] (https://ej2.syncfusion.com/products/images/treemap/readme.gif)

> TreeMap is part of Syncfusion Essential JS 2 commercial program. License is available in two models Community and Paid. Please refer the license file for more information. License can be obtained by registering at [https://www.syncfusion.com/downloads/essential-js2](https://www.syncfusion.com/downloads/essential-js2?utm_source=npm&utm_campaign=treemap)

## Setup

To install TreeMap and its dependent packages, use the following command

```sh
npm install @syncfusion/ej2-treemap
```

## Resources

* [Getting Started](https://ej2.syncfusion.com/documentation/treemap/getting-started.html?lang=typescript)
* [View Online Demos](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/default.html)
* [Product Page](https://www.syncfusion.com/javascript-ui-controls/treemap)

## Supported Frameworks

TreeMap component is also offered in following list of frameworks.

1. [Angular](https://www.npmjs.com/package/@syncfusion/ej2-ng-treemap?utm_source=npm&utm_campaign=treemap)
2. [React](https://www.npmjs.com/package/@syncfusion/ej2-react-treemap?utm_source=npm&utm_campaign=treemap)
3. [Vue.js](https://www.npmjs.com/package/@syncfusion/ej2-vue-treemap?utm_source=npm&utm_campaign=treemap)
4. [ASP.NET Core](https://aspdotnetcore.syncfusion.com/TreeMap/Default#/material)
5. [ASP.NET MVC](https://aspnetmvc.syncfusion.com/TreeMap/Default#/material)
6. [JavaScript (ES5)](https://www.syncfusion.com/javascript-ui-controls/treemap)

## Use case samples

* Olympic medal categories details ([Live Demo](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/customization.html))
* Countries population details ([Live Demo](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/drilldown.html))

## Key Features

* [**Data sources**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/pie.html) - Binds the tree map component with an array of JSON objects or DataManager. Both the heirarcical and flat collection data sources are supported.
* [**Levels**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/default.html) - Renders with any number of levels and items.
* [**Layout**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/layout.html) - Supports four types of layouts: square, horizontal, vertical, and auto.
* [**Drill-down**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/drilldown.html) - Provides drill-down option to have a closer look at the lower level of a hierarchy.
* [**Data label**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/label.html) - Provides additional information about the nodes.
* [**Label template**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/customization.html) - Uses any custom HTML element as data label for each node.
* [**Color mapping**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/label.html) - Applies colors to the nodes based on various conditions. Tree map supports three types of color mapping: range, equal, and desaturation.
* [**Legend**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/election.html) - Denotes the color mapping categories.
* [**Selection and Highlight**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/selection.html) - Supports selecting or highlighting the nodes to bring center of attraction.
* [**Tooltip**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/tooltip.html) - Provides additonal information about the nodes on mouse hover.
* [**Print and Export**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/print.html) - Provides options to print and export the rendered tree map for future use.

## Support

Product support is available for through following mediums.

* Creating incident in Syncfusion [Direct-trac](https://www.syncfusion.com/support/directtrac/incidents?utm_source=npm&utm_campaign=treemap) support system or [Community forum](https://www.syncfusion.com/forums/essential-js2?utm_source=npm&utm_campaign=treemap).
* New [GitHub issues](https://github.com/syncfusion/ej2-javascript-ui-controls/issues).
* Ask your query in Stack Overflow with tag `syncfusion`, `ej2`.

## License

Check the license detail [here](https://github.com/syncfusion/ej2-javascript-ui-controls/blob/master/controls/treemap/license?utm_source=npm&utm_campaign=treemap).

## Changelog

Check the changelog [here](https://github.com/syncfusion/ej2-javascript-ui-controls/blob/master/controls/treemap/CHANGELOG.md?utm_source=npm&utm_campaign=treemap)

© Copyright 2018 Syncfusion, Inc. All Rights Reserved. The Syncfusion Essential Studio license and copyright applies to this distribution.

==> ej2-treemap-17.2.34.tgz: package/README.md <==
# ej2-treemap

The tree map control provides a simple and effective way to visualize flat or hierarchical data as clustered rectangles with a specific, weighted attribute determining the size of each rectangle.

![TreeMap] (https://ej2.syncfusion.com/products/images/treemap/readme.gif)

> TreeMap is part of Syncfusion Essential JS 2 commercial program. License is available in two models Community and Paid. Please refer the license file for more information. License can be obtained by registering at [https://www.syncfusion.com/downloads/essential-js2](https://www.syncfusion.com/downloads/essential-js2?utm_source=npm&utm_campaign=treemap)

## Setup

To install TreeMap and its dependent packages, use the following commands

```sh
npm install @syncfusion/ej2-treemap
```

## Resources

* [Getting Started](https://ej2.syncfusion.com/documentation/treemap/getting-started.html?lang=typescript)
* [View Online Demos](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/default.html)
* [Product Page](https://www.syncfusion.com/products/javascript/treemap)

## Supported Frameworks

TreeMap component is also offered in following list of frameworks.

1. [Angular](https://www.npmjs.com/package/@syncfusion/ej2-ng-treemap?utm_source=npm&utm_campaign=treemap)
2. [React](https://www.npmjs.com/package/@syncfusion/ej2-react-treemap?utm_source=npm&utm_campaign=treemap)
3. [Vue.js](https://www.npmjs.com/package/@syncfusion/ej2-vue-treemap?utm_source=npm&utm_campaign=treemap)
4. [ASP.NET Core](https://aspdotnetcore.syncfusion.com/TreeMap/Default#/material)
5. [ASP.NET MVC](https://aspnetmvc.syncfusion.com/TreeMap/Default#/material)
6. [JavaScript (ES5)](https://www.syncfusion.com/products/javascript/treemap)

## Use case samples

* Olympic medal categories details ([Live Demo](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/customization.html))
* Countries population details ([Live Demo](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/drilldown.html))

## Key Features

* [**Data sources**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/pie.html) - Binds the tree map component with an array of JSON objects or DataManager. Both the heirarcical and flat collection data sources are supported.
* [**Levels**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/default.html) - Renders with any number of levels and items.
* [**Layout**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/layout.html) - Supports four types of layouts: square, horizontal, vertical, and auto.
* [**Drill-down**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/drilldown.html) - Provides drill-down option to have a closer look at the lower level of a hierarchy.
* [**Data label**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/label.html) - Provides additional information about the nodes.
* [**Label template**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/customization.html) - Uses any custom HTML element as data label for each node.
* [**Color mapping**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/label.html) - Applies colors to the nodes based on various conditions. Tree map supports three types of color mapping: range, equal, and desaturation.
* [**Legend**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/election.html) - Denotes the color mapping categories.
* [**Selection and Highlight**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/selection.html) - Supports selecting or highlighting the nodes to bring center of attraction.
* [**Tooltip**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/tooltip.html) - Provides additonal information about the nodes on mouse hover.
* [**Print and Export**](https://ej2.syncfusion.com/demos/?utm_source=npm&utm_campaign=treemap#/material/treemap/print.html) - Provides options to print and export the rendered tree map for future use.

## Support

Product support is available for through following mediums.

* Creating incident in Syncfusion [Direct-trac](https://www.syncfusion.com/support/directtrac/incidents?utm_source=npm&utm_campaign=treemap) support system or [Community forum](https://www.syncfusion.com/forums/essential-js2?utm_source=npm&utm_campaign=treemap).
* New [GitHub issues](https://github.com/syncfusion/ej2-javascript-ui-controls/issues).
* Ask your query in Stack Overflow with tag `syncfusion`, `ej2`.

## License

Check the license detail [here](https://github.com/syncfusion/ej2-javascript-ui-controls/blob/master/controls/treemap/license?utm_source=npm&utm_campaign=treemap).

## Changelog

Check the changelog [here](https://github.com/syncfusion/ej2-javascript-ui-controls/blob/master/controls/treemap/CHANGELOG.md?utm_source=npm&utm_campaign=treemap)

© Copyright 2019 Syncfusion, Inc. All Rights Reserved. The Syncfusion Essential Studio license and copyright applies to this distribution.
